/*****************************************************************************************
 ** File     : AboutDlg.cpp
 ** Date     : 03/24/2002
 ** Author   : Osama Dengler <osama@denglernet.de>
 ** Abstract : Extended CRegKey class fot convinient registry access.
 **
 ** Copyright (C) Osama Dengler 2002
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *****************************************************************************************/
#include "StdAfx.h"
#include "PwdFltAdmin.h"

/******************************************************************************************
 ** Name       : CMyRegKey
 ** Purpose    : Create and initialize a new CMyRegKey object derived from CRegKey.
 ** Parameters : -/-
 ** Return     : -/-
 ** Description: -/-
 ******************************************************************************************/
CMyRegKey::CMyRegKey() : CRegKey()
{
	LONG Status;
	DWORD Disposition;

	/*
	 * Call the base class constructor
	 */
	CRegKey::CRegKey();

	/*
	 * Open the registry key. If it doesn't exist, create it.
	 */
	Status=Create(	HKEY_LOCAL_MACHINE,
					_T("Software\\OpenAuth\\PasswordFilter"),
					REG_NONE,
					REG_OPTION_NON_VOLATILE,
					KEY_ALL_ACCESS,
					NULL,
					&Disposition);

	if(ERROR_SUCCESS == Status)
		/*
		 * Set flag for success
		 */
		m_IsOpen=TRUE;
	else
	{
		if(ERROR_ACCESS_DENIED == Status)
			MessageBox(NULL, _T("Unable to open the registry - Access denied."), _T("Error"), MB_OK);
		else
			MessageBox(NULL, _T("Unable to open the registry."), _T("Error"), MB_OK);

		/*
		 * Set flag for failure
		 */
		m_IsOpen=FALSE;
	}
}

/******************************************************************************************
 ** Name       : ~CMyRegKey
 ** Purpose    : Destructor for the CMyRegKey class.
 ** Parameters : -/-
 ** Return     : -/-
 ** Description: -/-
 ******************************************************************************************/
CMyRegKey::~CMyRegKey()
{
	/*
	 * Close the key if it is still open.
	 */
	if(m_IsOpen) Close();

	/*
	 * Call the base class destructor.
	 */
	CRegKey::~CRegKey();
}

/******************************************************************************************
 ** Name       : QueryValue
 ** Purpose    : Retrieve a string value from the registry.
 ** Parameters : Dest       -> Destination Cstring
 **              pValueName -> Name of the registry key value
 ** Return     : TRUE -> success, FALSE -> failure.
 ** Description: -/-
 ******************************************************************************************/
BOOL CMyRegKey::QueryValue(CString &Dest, PTSTR pValueName)
{
	LONG Status;
	DWORD DataLength=MAX_PATH;

	/*
	 * Check for read without open
	 */
	ASSERT(m_IsOpen);
	if(!m_IsOpen) return(FALSE);

	/*
	 * Prepare (=clear) the destination string.
	 */
	Dest.Empty();

	/*
	 * Retrieve the value.
	 */
	Status=CRegKey::QueryValue(Dest.GetBuffer(MAX_PATH), pValueName, &DataLength);

	/*
	 * Release the buffer so that the use counter is decremented.
	 */
	Dest.ReleaseBuffer();
	
	return(ERROR_SUCCESS == Status);
}

/******************************************************************************************
 ** Name       : QueryValue
 ** Purpose    : Retrieve a BOOL value from the registry.
 ** Parameters : pDest      -> Destination BOOL
 **              pValueName -> Name of the registry key value
 ** Return     : TRUE -> success, FALSE -> failure.
 ** Description: -/-
 ******************************************************************************************/
BOOL CMyRegKey::QueryValue(BOOL *pDest, PTSTR pValueName)
{
	LONG Status;
	DWORD Tmp=0;

	/*
	 * Check for read without open
	 */
	ASSERT(m_IsOpen);
	if(!m_IsOpen) return(FALSE);

	Status=CRegKey::QueryValue(Tmp, pValueName);

	*pDest=(BOOL)Tmp;

	return(ERROR_SUCCESS == Status);
}

/******************************************************************************************
 ** Name       : SetValue
 ** Purpose    : Save a CString value into the registry.
 ** Parameters : Value      -> Value to save
 **              pValueName -> Name of the registry key value
 ** Return     : TRUE -> success, FALSE -> failure.
 ** Description: -/-
 ******************************************************************************************/
BOOL CMyRegKey::SetValue(CString &Value, PTSTR pValueName)
{
	return(CRegKey::SetValue((LPCTSTR)Value, pValueName) == ERROR_SUCCESS);
}

/******************************************************************************************
 ** Name       : SetValue
 ** Purpose    : Save a BOOL value into the registry.
 ** Parameters : Value      -> Value to save
 **              pValueName -> Name of the registry key value
 ** Return     : TRUE -> success, FALSE -> failure.
 ** Description: -/-
 ******************************************************************************************/
BOOL CMyRegKey::SetValue(BOOL Value, PTSTR pValueName)
{
	return(CRegKey::SetValue((DWORD)Value, pValueName) == ERROR_SUCCESS);
}
