/*****************************************************************************************
 ** File     : PwdFltAdminDlg.cpp
 ** Date     : 03/24/2002
 ** Author   : Osama Dengler <osama@denglernet.de>
 ** Abstract : Class for the main application dialog.
 **
 ** Copyright (C) Osama Dengler 2002
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *****************************************************************************************/
#include "StdAfx.h"
#include "PwdFltAdmin.h"

/******************************************************************************************
 ** Name       : CPwdFltAdminDlg
 ** Purpose    : Create and initialize a new CPwdFltAdminDlg object.
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: standard MSDN
 ******************************************************************************************/
CPwdFltAdminDlg::CPwdFltAdminDlg(CWnd* pParent) : CDialog(CPwdFltAdminDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CPwdFltAdminDlg)
	m_BaseDN = _T("");
	m_BindDN = _T("");
	m_BindPW = _T("");
	m_ForceLDAPv2 = FALSE;
	m_ForceLDAPv3 = FALSE;
	m_LdapServer = _T("");
	m_UseSSL = FALSE;
	//}}AFX_DATA_INIT

	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

/******************************************************************************************
 ** Name       : DoDataExchange
 ** Purpose    : DDX for the CPwdFltAdminDlg class.
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: standard MSDN
 ******************************************************************************************/
void CPwdFltAdminDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPwdFltAdminDlg)
	DDX_Text(pDX, IDC_BASE_DN, m_BaseDN);
	DDX_Text(pDX, IDC_BIND_DN, m_BindDN);
	DDX_Text(pDX, IDC_BIND_PW, m_BindPW);
	DDX_Check(pDX, IDC_FORCE_LDAPV2, m_ForceLDAPv2);
	DDX_Check(pDX, IDC_FORCE_LDAPV3, m_ForceLDAPv3);
	DDX_Text(pDX, IDC_LDAP_SERVER, m_LdapServer);
	DDX_Check(pDX, IDC_USE_SSL, m_UseSSL);
	//}}AFX_DATA_MAP

	/*
	 * update the UI upon first initialization
	 */
	if(!pDX->m_bSaveAndValidate)
	{
		OnForceLdapv2();
		OnForceLdapv3();
	}
}

/******************************************************************************************
 ** Name       : MessageMap
 ** Purpose    : Message map for the CPwdFltAdminDlg class.
 ******************************************************************************************/
BEGIN_MESSAGE_MAP(CPwdFltAdminDlg, CDialog)
	//{{AFX_MSG_MAP(CPwdFltAdminDlg)
	ON_WM_SYSCOMMAND()
	ON_WM_DESTROY()
	ON_BN_CLICKED(IDC_FORCE_LDAPV2, OnForceLdapv2)
	ON_BN_CLICKED(IDC_FORCE_LDAPV3, OnForceLdapv3)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/******************************************************************************************
 ** Name       : OnInitDialog
 ** Purpose    : WM_INITDLG handler
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: standard MSDN
 ******************************************************************************************/
BOOL CPwdFltAdminDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	/*
	 * Add the "about..." menuitem to the system menu
	 */
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{	
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	/*
	 * Set icon for this dialog
	 */
	SetIcon(m_hIcon, TRUE);
	SetIcon(m_hIcon, FALSE);
	
	/*
	 * Open the registry. If the key doesn't exist, create it.
	 */
	if(!OpenRegistry()) EndDialog(FALSE);
	else
	{

		/*
		 * Read the registry values if there are any
		 */
		ReadRegValues();

		/*
		 * Synchronize the dialog fields with the member variables
		 */
		UpdateData(FALSE);
	
		/*
		 * Set the focus to the topmost dialog field
		 */
		GetDlgItem(IDC_LDAP_SERVER)->SetFocus();
	}

	/*
	 * FALSE doesn't move the focus to the default button.
	 */
	return(FALSE);
}

/******************************************************************************************
 ** Name       : OnSysCommand
 ** Purpose    : WM_SYSCOMMAND handler
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: Display the aboutbox - standard MSDN
 ******************************************************************************************/
void CPwdFltAdminDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	/*
	 * check for the aboutbox-command
	 */
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		/*
		 * Display the dialog
		 */
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		/*
		 * Pass message to the standard queue.
		 */
		CDialog::OnSysCommand(nID, lParam);
	}
}

/******************************************************************************************
 ** Name       : OnDestroy
 ** Purpose    : WM_DESTROY handler
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: Clean up - standard MSDN
 ******************************************************************************************/
void CPwdFltAdminDlg::OnDestroy()
{
	/*
	 * Shutdown WinHelp.
	 */
	WinHelp(0L, HELP_QUIT);

	/*
	 * Free all memory.
	 */
	delete(m_pRegKey);

	/*
	 * Call standard desctructor.
	 */
	CDialog::OnDestroy();
}

/******************************************************************************************
 ** Name       : OnForceLdapv2
 ** Purpose    : WM_BUTTONDWN handler for the "Force LDAPv2" button. Keep the UI consistent.
 ** Parameters : -/-
 ** Return     : -/-
 ** Description: "Force LDAPv2" and "Force LDAPv3" are mutually exclusive.
 ******************************************************************************************/
void CPwdFltAdminDlg::OnForceLdapv2() 
{
	if(IsDlgButtonChecked(IDC_FORCE_LDAPV2))
		/*
		 * Disable the "Force LDAPv3" Button.
		 */
		GetDlgItem(IDC_FORCE_LDAPV3)->EnableWindow(FALSE);
	else
		/*
		 * Enable the "Force LDAPv3" Button.
		 */
		GetDlgItem(IDC_FORCE_LDAPV3)->EnableWindow(TRUE);

}

/******************************************************************************************
 ** Name       : OnForceLdapv3
 ** Purpose    : WM_BUTTONDWN handler for the "Force LDAPv3" button. Keep the UI consistent.
 ** Parameters : -/-
 ** Return     : -/-
 ** Description: "Force LDAPv3" and "Force LDAPv2" are mutually exclusive.
 ******************************************************************************************/
void CPwdFltAdminDlg::OnForceLdapv3() 
{
	if(IsDlgButtonChecked(IDC_FORCE_LDAPV3))
		/*
		 * Disable the "Force LDAPv2" Button.
		 */
		GetDlgItem(IDC_FORCE_LDAPV2)->EnableWindow(FALSE);
	else
		/*
		 * Enable the "Force LDAPv2" Button.
		 */
		GetDlgItem(IDC_FORCE_LDAPV2)->EnableWindow(TRUE);
}

/******************************************************************************************
 ** Name       : OnOK
 ** Purpose    : WM_BUTTONDWN handler for the "OK" button. Save the settings.
 ** Parameters : standard MSDN
 ** Return     : standard MSDN
 ** Description: standard MSDN
 ******************************************************************************************/
void CPwdFltAdminDlg::OnOK() 
{
	/*
	 * Synchronize member variables with the dialog field contents.
	 */
	UpdateData(TRUE);

	/*
	 * Write to the registry.
	 */
	WriteRegValues();

	/*
	 * Inform the user.
	 */
	MessageBox(_T("Settings will take effect after next reboot."), _T("Information"), MB_OK);

	/*
	 * Call the base class method.
	 */
	CDialog::OnOK();
}

/******************************************************************************************
 ** Name       : OpenRegistry
 ** Purpose    : Open the registry key.
 ** Parameters : -/-
 ** Return     : TRUE -> success, FALSE -> fail.
 ** Description: Open the OpenAuth registry key. If the Key doesn't already exist it is
 **              created.
 ******************************************************************************************/
BOOL CPwdFltAdminDlg::OpenRegistry()
{
	m_pRegKey=new(CMyRegKey);

	return(m_pRegKey->m_IsOpen);
}

/******************************************************************************************
 ** Name       : ReadRegValues
 ** Purpose    : Read the registry-stored values to the member-variables.
 ** Parameters : -/-
 ** Return     : TRUE -> success, FALSE -> fail.
 ** Description: -/-
 ******************************************************************************************/
BOOL CPwdFltAdminDlg::ReadRegValues()
{
	m_pRegKey->QueryValue(m_LdapServer, _T("LDAP Server"));

	m_pRegKey->QueryValue(m_BaseDN, _T("Base DN"));

	m_pRegKey->QueryValue(m_BindDN, _T("Bind DN"));

	m_pRegKey->QueryValue(m_BindPW, _T("Bind PW"));
	
	m_pRegKey->QueryValue(&m_ForceLDAPv2, _T("Force LDAPv2"));

	m_pRegKey->QueryValue(&m_ForceLDAPv3, _T("Force LDAPv3"));

	m_pRegKey->QueryValue(&m_UseSSL, _T("Use SSL"));

	return(TRUE);
}

/******************************************************************************************
 ** Name       : WriteRegValues
 ** Purpose    : Write the member-variables to the registry.
 ** Parameters : -/-
 ** Return     : TRUE -> success, FALSE -> fail.
 ** Description: -/-
 ******************************************************************************************/
BOOL CPwdFltAdminDlg::WriteRegValues()
{
	m_pRegKey->SetValue(m_LdapServer, _T("LDAP Server"));

	m_pRegKey->SetValue(m_BaseDN, _T("Base DN"));

	m_pRegKey->SetValue(m_BindDN, _T("Bind DN"));

	m_pRegKey->SetValue(m_BindPW, _T("Bind PW"));
	
	m_pRegKey->SetValue(m_ForceLDAPv2, _T("Force LDAPv2"));

	m_pRegKey->SetValue(m_ForceLDAPv3, _T("Force LDAPv3"));

	m_pRegKey->SetValue(m_UseSSL, _T("Use SSL"));

	return(TRUE);
}
